Project hosting with Launchpad
==============================

`Launchpad`_ hosts the manila project. The manila project homepage on Launchpad is
http://launchpad.net/manila.

Launchpad credentials
---------------------

Creating a login on Launchpad is important even if you don't use the Launchpad
site itself, since Launchpad credentials are used for logging in on several
OpenStack-related sites. These sites include:

 * `Wiki`_
 * Gerrit (see :doc:`gerrit`)

Mailing list
------------

The mailing list email is ``openstack@lists.launchpad.net``. This is a common
mailing list across the OpenStack projects. To participate in the mailing list:

#. Join the `Manila Team`_ on Launchpad.
#. Subscribe to the list on the `OpenStack Team`_ page on Launchpad.

The mailing list archives are at https://lists.launchpad.net/openstack.


Bug tracking
------------

Report manila bugs at https://bugs.launchpad.net/manila

Feature requests (Blueprints)
-----------------------------

Manila uses Launchpad Blueprints to track feature requests. Blueprints are at
https://blueprints.launchpad.net/manila.

Technical support (Answers)
---------------------------

Manila uses Launchpad Answers to track manila technical support questions. The manila
Answers page is at https://answers.launchpad.net/manila.

Note that the `OpenStack Forums`_ (which are not hosted on Launchpad) can also
be used for technical support requests.

.. _Launchpad: http://launchpad.net
.. _Wiki: http://wiki.openstack.org
.. _Manila Team: https://launchpad.net/~manila
.. _OpenStack Team: https://launchpad.net/~openstack
.. _OpenStack Forums: http://forums.openstack.org/
